@@ -332,22 +332,12 @@ x.__repr__() <==> repr(x)
 x.__delitem__(key) <==> del x[key]
 
 '''
-#        self._conversion_term_type.pop(term, None)
-        self._parameters.remove(term)
-        self._ancillaries.remove(term)
+        self._parameters.remove(key)
+        self._ancillaries.remove(key)
 
         super(CoordinateReference, self).__delitem__(key)
     #--- End: def
 
-#    def __setitem__(self, key, value):
-#        '''
-#
-#x.__setitem__(key) <==> x[key] = value
-#
-#'''
-#        super(CoordinateReference, self).__setitem__(key, value)
-#    #--- End: def
-
     def __str__(self):
         '''
 
@@ -1314,7 +1304,7 @@ reference.
                 continue
 
             value = Data.asdata(value)
-            
+
             cu = _canonical_units.get(term, None)
             if cu is not None:
                 if value.Units.equivalent(cu):
