@@ -1,9 +1,12 @@
+import datetime
 import os
-import numpy
-import cf
 import unittest
 import inspect
 
+import numpy
+
+import cf
+
 class VariableTest(unittest.TestCase):
     def setUp(self):
         self.filename = os.path.join(os.path.dirname(os.path.abspath(__file__)),
@@ -25,17 +28,17 @@ class VariableTest(unittest.TestCase):
             self.assertTrue(f.mid_range() == f.data.mid_range(squeeze=True))
             self.assertTrue(f.min()       == f.data.min(squeeze=True))
             self.assertTrue(f.range()     == f.data.range(squeeze=True))
-            self.assertTrue(f.sd()        == f.data.sd(squeeze=True))
+            self.assertTrue(f.sd()        == f.data.sd(squeeze=True, ddof=0))
             self.assertTrue(f.sum()       == f.data.sum(squeeze=True))
-            self.assertTrue(f.var()       == f.data.var(squeeze=True))
+            self.assertTrue(f.var()       == f.data.var(squeeze=True, ddof=0))
         #--- End: for    
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
         
 #--- End: class
-        
+
 if __name__ == '__main__':
-    print 'cf-python version:', cf.__version__
-    print 'cf-python path:'   , os.path.abspath(cf.__file__)
-    print''
+    print 'Run date:', datetime.datetime.utcnow()
+    cf.environment()
+    print
     unittest.main(verbosity=2)
